from setuptools import setup

setup(name='udacity_foundation_distributions',
      version='0.1',
      description='Gaussian and Binomial Distributions',
      packages=['distributions'],
      author="prashant arora",
      author_email="prashantarora998@gmail.com",
      zip_safe=False)
